@@ -33,7 +33,7 @@ from tinydav.exception import HTTPError, HTTPUserError, HTTPServerError
 
 __author__ = "Manuel Hermann <manuel-hermann@gmx.net>"
 __license__ = "LGPL"
-__version__ = "0.6.1"
+__version__ = "0.6.2"
 
 __all__ = (
     "HTTPError", "HTTPUserError", "HTTPServerError",
@@ -334,10 +334,7 @@ class WebDAVLockResponse(WebDAVResponse):
             # RFC 2518, 12.7.2 shared XML Element
             # <!ELEMENT shared EMPTY >
             scope = ACTIVELOCK + "/{DAV:}lockscope/*"
-            try:
-                self._lockscope = self._etree.find(scope)
-            except IndexError:
-                pass
+            self._lockscope = self._etree.find(scope)
         return self._locktype
 
     @property
@@ -347,10 +344,7 @@ class WebDAVLockResponse(WebDAVResponse):
             # RFC 2518, 12.8 locktype XML Element
             # <!ELEMENT locktype (write) >
             locktype = ACTIVELOCK + "/{DAV:}locktype/*"
-            try:
-                self._locktype = self._etree.find(locktype)
-            except IndexError:
-                pass
+            self._locktype = self._etree.find(locktype)
         return self._locktype
 
     @property
@@ -371,8 +365,6 @@ class WebDAVLockResponse(WebDAVResponse):
             # <!ELEMENT owner ANY>
             owner = ACTIVELOCK + "/{DAV:}owner"
             self._owner = self._etree.find(owner)
-            if not self._owner:
-                self._owner = None
         return self._owner
 
     @property
@@ -383,8 +375,6 @@ class WebDAVLockResponse(WebDAVResponse):
             # <!ELEMENT timeout (#PCDATA) >
             timeout = ACTIVELOCK + "/{DAV:}timeout"
             self._timeout = self._etree.findtext(timeout)
-            if not self._timeout:
-                self._timeout = None
         return self._timeout
 
     @property
@@ -415,7 +405,6 @@ class MultiStatusResponse(int):
                   XML structure had.
 
     """
-
     def __new__(cls, response):
         """Create instance with status code as int value."""
         # RFC 2518, 12.9.1 response XML Element
@@ -479,11 +468,11 @@ class MultiStatusResponse(int):
             yield tagname
 
     def items(self):
-        """Return list of 2-tuples with propertyname and value."""
+        """Return list of 2-tuples with propertyname and ElementTree element."""
         return list(self.iteritems())
 
     def iteritems(self, cut_dav_ns=True):
-        """Iterate list of 2-tuples with propertyname and value.
+        """Iterate list of 2-tuples with propertyname and ElementTree element.
 
         cut_dav_ns -- No namespaces for DAV properties when this is True.
 
@@ -495,7 +484,7 @@ class MultiStatusResponse(int):
             tagname = prop.tag
             if cut_dav_ns and tagname.startswith("{DAV:}"):
                 tagname = tagname[6:]
-            yield (tagname, prop.text)
+            yield (tagname, prop)
 
     def get(self, key, default=None, namespace=None):
         """Return value for requested property.
@@ -645,9 +634,9 @@ class HTTPClient(object):
             con.request(method, uri, content, headers)
             response = self.ResponseType(con.getresponse())
             if 400 <= response < 500:
-                response = HTTPUserError(response, method)
+                response = HTTPUserError(response)
             elif 500 <= response < 600:
-                response = HTTPServerError(response, method)
+                response = HTTPServerError(response)
 
         if self.cookie is not None:
             # Get response object suitable for cookielib
@@ -920,7 +909,7 @@ class CoreWebDAVClient(HTTPClient):
         # Consequently, the Destination header MUST be present on all MOVE
         # methods and MUST follow all COPY requirements for the COPY part of
         # the MOVE method.
-        # RFC 2517, 9.3 Destination Header
+        # RFC 2518, 9.3 Destination Header
         # Destination = "Destination" ":" absoluteURI
         headers["Destination"] = util.make_absolute(self, destination)
         # RFC 2518, 8.8.3 COPY for Collections
@@ -974,7 +963,7 @@ class CoreWebDAVClient(HTTPClient):
 
         """
         namespaces = dict() if (namespaces is None) else namespaces
-        # RFC 2517, 8.1 PROPFIND
+        # RFC 2518, 8.1 PROPFIND
         # A client may submit a Depth header with a value of "0", "1", or
         # "infinity" with a PROPFIND on a collection resource with internal
         # member URIs.
@@ -1007,7 +996,7 @@ class CoreWebDAVClient(HTTPClient):
         Raise HTTPServerError on 5xx HTTP status codes.
 
         """
-        # RFC 2517, 12.13 propertyupdate XML element
+        # RFC 2518, 12.13 propertyupdate XML element
         # <!ELEMENT propertyupdate (remove | set)+ >
         if not any((setprops, delprops)):
             raise ValueError("setprops and/or delprops must be given")
@@ -1029,7 +1018,7 @@ class CoreWebDAVClient(HTTPClient):
         """
         headers = dict() if (headers is None) else headers
         if uri.endswith("/"):
-            # RFC 2517, 8.6.2 DELETE for Collections
+            # RFC 2518, 8.6.2 DELETE for Collections
             # A client MUST NOT submit a Depth header with a DELETE on a
             # collection with any value but infinity.
             headers["Depth"] = "infinity"
@@ -1098,7 +1087,7 @@ class CoreWebDAVClient(HTTPClient):
 
         """
         (uri, headers) = self._prepare(uri, headers)
-        # RFC 2517, 9.8 Timeout Request Header
+        # RFC 2518, 9.8 Timeout Request Header
         # TimeOut = "Timeout" ":" 1#TimeType
         # TimeType = ("Second-" DAVTimeOutVal | "Infinite" | Other)
         # DAVTimeOutVal = 1*digit
@@ -1116,7 +1105,7 @@ class CoreWebDAVClient(HTTPClient):
                     raise ValueError("timeout too big")
                 value = "Second-%d" % timeout
             headers["Timeout"] = value
-        # RFC 2517, 8.10.4 Depth and Locking
+        # RFC 2518, 8.10.4 Depth and Locking
         # Values other than
         # 0 or infinity MUST NOT be used with the Depth header on a LOCK
         # method.
@@ -1185,7 +1174,8 @@ class ExtendedWebDAVClient(CoreWebDAVClient):
         depth -- Either 0 or 1 or "infinity". Default is zero.
         properties -- If given, an iterable with all requested properties is
                       expected.
-        elements -- An iterable with additional XML elements.
+        elements -- An iterable with additional XML (ElementTree) elements to
+                    append to the version-tree.
         namespaces -- Mapping with namespaces for given properties, if needed.
         headers -- If given, must be a mapping with headers to set.
 
